@@ -2,7 +2,7 @@
 #
 # Encoding of Arabic: Tim Buckwalter's Notation ##################################### 2003/06/19
 
-# $Id: Buckwalter.pm,v 1.11 2005/04/16 06:04:16 smrz Exp $
+# $Id: Buckwalter.pm,v 1.12 2005/11/28 00:46:40 smrz Exp $
 
 package Encode::Arabic::Buckwalter;
 
@@ -13,7 +13,7 @@ use warnings;
 
 use Scalar::Util 'blessed';
 
-our $VERSION = do { my @r = q$Revision: 1.11 $ =~ /\d+/g; sprintf "%d." . "%02d" x $#r, @r };
+our $VERSION = do { my @r = q$Revision: 1.12 $ =~ /\d+/g; sprintf "%d." . "%02d" x $#r, @r };
 
 
 use Encode::Encoding;
@@ -257,7 +257,7 @@ Encode::Arabic::Buckwalter - Perl extension for Tim Buckwalter's transliteration
 
 =head1 REVISION
 
-    $Revision: 1.11 $        $Date: 2005/04/16 06:04:16 $
+    $Revision: 1.12 $        $Date: 2005/11/28 00:46:40 $
 
 
 =head1 SYNOPSIS
@@ -368,9 +368,9 @@ Arabeyes Duali Project  L<http://www.arabeyes.org/project.php?proj=Duali>
 
 =head1 AUTHOR
 
-Otakar Smrz, L<http://ckl.mff.cuni.cz/smrz/>
+Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
 
-    eval { 'E<lt>' . 'smrz' . "\x40" . ( join '.', qw 'ckl mff cuni cz' ) . 'E<gt>' }
+    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
 
 Perl is also designed to make the easy jobs not that easy ;)
 
